<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="it" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Categoria:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Avvia torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Salta controllo hash</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Crea sottocartella</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Modo gestione torrent:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Tutti</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Non categorizzati</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Aggiungi categoria...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Rimuovi categoria</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Rimuovi categorie inutilizzate</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Riprendi torrent</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Metti in pausa torrent</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Elimina torrent</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nuova Categoria</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Modifica categoria...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Chiudi qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Solo un collegamento per riga</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Il limite globale di velocità di invio deve essere maggiore di 0 o disattivato.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Il limite globale di velocità di scaricamento deve essere maggiore di 0 o disattivato.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Il limite alternativo per l'invio deve essere maggiore di 0 o disattivato.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Il limite alternativo per lo scaricamento deve essere maggiore di 0 o disattivato.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Il numero massimo di scaricamenti attivi deve essere maggiore di -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Il numero massimo di invii attivi deve essere maggiore di -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Il numero massimo di torrent attivi deve essere maggiore di -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Il limite per il numero massimo di connessioni deve essere 0 o disattivato.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Il limite per il numero di connessioni per torrent deve essere 0 o disattivato.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Il numero massimo di posizioni in invio deve essere 0 o disattivato.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Impossibile salvare le preferenze, qBittorrent potrebbe essere irraggiungibile.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent su Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Il limite rapporto di condivisione deve essere tra 0 e 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>Il limite temporale di condivisione deve essere tra 0 e 525600 minuti.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>La porta usata per le connessioni in entrata deve essere compresa tra 1 e 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>La porta usata per l'interfaccia web deve essere compresa tra 1 e 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Impossibile effettuare l'accesso, probabilmente qBittorrent non è raggiungibile.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Username o password errati.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome utente</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Autori originari</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Carica Torrent</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Salva file nel percorso:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Cookie:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Inserisci cartella</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Più informazioni</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Informazioni sui certificati</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Imposta posizione</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Limita velocità di invio</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Limita velocità di scaricamento</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Rinomina torrent</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Altro...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Lunedì</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Martedì</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Mercoledì</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Giovedì</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Venerdì</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Sabato</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Domenica</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Disconnessione</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Scarica torrent dal loro URL o da collegamento magnet</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Carica torrent locale</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Sei sicuro di voler eliminare i torrent selezionati dall'elenco trasferimenti?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>Il client qBittorrent non è raggiungibile</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>Numero globale limite slot upload  deve essere maggiore di 0 o disabilitato.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Nome categoria non valido.\nNon usare nessun carattere speciale nel nome categoria.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Impossibile creare la categoria</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>La soglia tasso upload deve essere maggiore di 0.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Spazio libero: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Il timer inattività torrent deve essere maggiore di 0.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Gestione salvataggi</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>La soglia tasso download deve essere maggiore di 0.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qbittorent si sta chiudendo</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Strumenti</translation>
    </message>
    <message>
        <source>File</source>
        <translation>File</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Opzioni...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Riprendi</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Priorità minima</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Priorità massima</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Diminuisci priorità</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Aumenta priorità</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Barra strumenti superiore</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Barra di stato</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Velocità nella barra del titolo</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Fai una donazione!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Riprendi tutti</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistiche</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Metti in pausa</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Metti in pausa tutti</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Aggiungi file torrent...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Guida in linea</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Aggiungi collegamento torrent...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sì</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Limite globale invio</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Limite globale scaricamento</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Sei sicuro di voler uscire da qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[D: %1, U: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Limiti alternativi velocità</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Motore di ricerca</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Filtro elenco torrent...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Trasferimenti</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Scaricamenti</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Connessione</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocità</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Interfaccia web</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Lingua</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Lingua Interfaccia Utente:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Notifica email al completamento dello scaricamento</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Lancia programma esterno al completamento del torrent</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>Filtraggio IP</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Pianifica l'uso di limiti di rapporto alternativi</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Accodamento torrent</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>Condividi torrent fino al raggiungimento del tempo di condivisione</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Aggiungi automaticamente questi server traccia ai nuovi scaricamenti:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Interfaccia utente web (Controllo remoto)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>Indirizzo IP:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Domini server:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Usa HTTPS invece di HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Salta autenticazione per i client in localhost</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Salta autenticazione per i client nelle sottoreti IP in lista bianca</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Aggiorna il mio nome dominio dinamico</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Salva torrent incompleti in:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Copia i file .torrent in:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Copia i file .torrent per gli scaricamenti completati in:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Prealloca lo spazio su disco per tutti i file</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Aggiungi l'estensione .!qB ai file incompleti</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Aggiungi automaticamente i torrent da:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>Server SMTP:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Questo server richiede una connessione sicura (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autenticazione</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome utente:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Password:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Protocollo abilitato:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP e µTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Porta di Ascolto</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Porta usata per le connessioni in entrata:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Usa UPnP / NAT-PMP per aprire le porte del mio router</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Usa porte diverse ad ogni avvio</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Limiti Connessioni</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Numero massimo di connessioni per torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Numero massimo globale di connessioni:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Numero massimo di connessioni in invio per torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Numero massimo globale di connessioni in invio:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Server Proxy</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Nessuno)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Porta:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Usa il proxy per le connessioni ai nodi</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>Disabilita connessioni non supportate dai proxy</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Usa il proxy solo per i torrent</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Percorso filtro (.dat, .p2p, p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Indirizzi IP messi al bando manualmente...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Applica ai server traccia</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Limiti di velocità globali</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Invio:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Scaricamento:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Limiti di velocità alternativi</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>Da:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>A:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Quando:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Ogni giorno</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Giorni feriali</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Fine settimana</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Impostazioni limiti di velocità</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Applica limiti di velocità al traffico di servizio</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Applica limiti di velocità al protocollo µTP</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Privacy</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Abilita DHT (rete decentralizzata) per trovare più nodi</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Abilita Scambio Nodi (PeX) per trovare più nodi</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Abilita Ricerca Locale Nodi per trovare più nodi</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Modalità di cifratura:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>Preferisci cifratura</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Esigi cifratura</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Disabilita cifratura</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Abilita modalità anonima</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Numero massimo di scaricamenti attivi:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Numero massimo di invii attivi:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Numero massimo di torrent attivi:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Non contare torrent lenti in questi limiti</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>Limitazione rapporto di condivisione</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>Distribuisci i torrent finché il loro rapporto raggiunge</translation>
    </message>
    <message>
        <source>then</source>
        <translation>poi</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>Mettili in pausa</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>Rimuovili</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Usa UPnP / NAT-PMP per aprire le porte del mio router</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Certificato:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Chiave:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Registra</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Nome dominio:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Parametri supportati (maiuscole/minuscole):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Nome torrent</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Categoria</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation type="vanished">%G: Etichette (separate da virgole)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Percorso contenuto (uguale al percorso radice per i torrent multi-file)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Percorso radice (primo percorso sottocartella torrent)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Percorso salvataggio</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Numero di file</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Dimensione torrent (byte)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Server traccia attuale</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Info hash</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Suggerimento: Incapsula i parametri con i segni di quotazione per evitare tagli del testo negli spazi bianchi (per esempio "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Il nome utente per l'interfaccia web deve essere lungo almeno 3 caratteri.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>La password per l'interfaccia web deve essere lunga almeno 6 caratteri.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuti</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Abilita protezione  clickjacking</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Abilita protezione CSRF (Cross-Site Request Forgery)</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Elimina file .torrent dopo completamento</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Soglia tasso download:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Soglia tasso upload:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Modifica password attuale</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatico</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Usa web UI alternativa</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Percorso predefinito salvataggio:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>Il percorso file web UI alternativa non può essere vuoto.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Non avviare automaticamente i download</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Commuta torrent in modo manuale</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Quando cambi la categoria torrent:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Rialloca i torrent relativi</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Applica limite tasso ai peer sulla LAN</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 significa illimitato</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Riposiziona torrent</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Quando modifichi percorso predefinito salvataggio:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Abilita validazione intestazione host</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sicurezza</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Quando modifichi percorso salvataggio categoria:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Crea sotto cartela per torrent con file multipli</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>secondi</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Commuta torrent relativi al modo manuale</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Percorso file:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuale</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Timer inattività torrent:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Modo predefinito gestione torrent:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>Quando aggiungi un torrent</translation>
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Flag</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Connessione</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Client</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Avanzamento</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Velocità scaricamento</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Velocità invio</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Scaricati</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Inviati</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Rilevanza</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>File</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Paese</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normale</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Alta</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Massima</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Server traccia</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Nodi</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>Sorgenti HTTP</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Contenuto</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Scaricati:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Trasferimento</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Durata attività:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Tempo stimato:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Inviati:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Distributori:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Velocità scaricamento:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Velocità invio:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Nodi:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Limite scaricamento:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Limite invio:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Sprecati:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Connessioni:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Commento:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Rapporto di condivisione:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Riannuncio tra:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Visto completo l'ultima volta:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Dimensione totale:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Parti:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Creato da:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Aggiunto il:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Completato il:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Creato il:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Hash torrent:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Percorso salvataggio:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Mai</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (ne hai %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 in questa sessione)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (max %2)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 in totale)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 in media)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Limite download:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Limite upload:</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Cartella Monitorata</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Aggira Posizione di Salvataggio</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Cartella monitorata</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Percorso di salvataggio predefinito</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Statistiche</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Statistiche utente</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Statistiche cache</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Hit lettura cache:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Tempo medio in coda:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Nodi connessi:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Rapporto condivisione da sempre:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Scaricamenti da sempre:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Spreco sessione:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Invii da sempre:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Dimensione buffer totale:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Statistiche prestazioni</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Lavori I/O in coda:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Sovraccarico cache scrittura:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Sovraccarico cache lettura:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Dimensione totale in coda:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 nodi</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Tutti (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>In scaricamento (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>In condivisione (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Completati (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Ripresi (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>In pausa (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Attivi (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Inattivi (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Con errori (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Tutti (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>In scaricamento (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>In condivisione (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Completati (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>In pausa (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Ripresi (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Attivi (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Inattivi (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Con errori (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Avanzamento</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Priorità scaricamento</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Rimanente</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Disponibilità</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Dimensione</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Avanzamento</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Stato</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Distributori</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Nodi</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Velocità scaricamento</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Velocità invio</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Rapporto</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Tempo stimato</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Etichette</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Aggiunto il</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Completato il</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Server traccia</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Limite di scaricamento</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Limiti di invio</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Scaricati</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Inviati</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Scaricamento sessione</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Invio sessione</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Rimanente</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Tempo attivo</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Percorso salvataggio</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Completati</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Limite rapporto di condivione</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Visto completo l'ultima volta</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Ultima attività</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Dimensione totale</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stato</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Nodi</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Messaggio</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Scaricati</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>URL tracker:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Aggiornamento...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>In elaborazione</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Disabilitato</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Non ancora connesso</translation>
    </message>
    <message>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/D</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Seed</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Non funzionante</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Copia URL tracker</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Aggiungi un nuovo tracker...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Modifica URL tracker...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Modifica tracker</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Leech</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Rimuovi tracker</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Finestra per l'aggiunta dei server traccia</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Elenco dei server traccia da aggiungere (uno per riga):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 fa</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>In allocazione</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>In pausa</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Completato</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Spostamento</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] In seed</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>In seed</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>In coda</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Errori</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] Download</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Download metadata</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Verifica</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>File mancanti</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>In coda per verifica</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Verifica dati recupero download</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>In stallo</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Stato</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Categorie</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Limitazione velocità scaricamento</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Limitazione velocità invio</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Riprendi</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Forza avvio</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Metti in pausa</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Limita rapporto di condivione...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Limita velocità di invio...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Limita velocità di scaricamento...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Muovi in alto</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Muovi in basso</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Muovi in cima</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Muovi in fondo</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Imposta percorso...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Copia nome</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>Copia hash</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Scarica la prima e l'ultima parte per prime</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Gestione Torrent Automatica</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Nuova...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Azzera</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Priorità</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Forza ricontrollo</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Copia collegamento magnet</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Modalità super distribuzione</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Rinomina...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Scarica in ordine sequenziale</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Forza ricontrollo</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nuova categoria</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Percorso</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Nuovo nome</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Imposta percorso</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Forza ri-annuncio</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Modifica categoria</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Percorso salvataggio</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Limitazione rapporto invio/scaricamento</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Usa limite condivisione globale</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Nessun limite condivisione</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Usa questo limite</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>rapporto</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuti</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Un client BitTorrent avanzato scritto in C++, basato sul toolkit Qt e libtorrent-rastebar.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Homepage:</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Forum:</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Bug Tracker:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Conferma cancellazione</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Elimina anche il relativo file dal disco fisso</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Conferma eliminazione - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Scarica da URL</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Scarica</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Aggiungi collegamenti torrent</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1h %2m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1g %2h</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Sconosciuta</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1m</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1m</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>Percorso salvataggio è vuoto</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Percorso plugin:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL o cartella locale</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Installa plugin</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Seed:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Tutti i plugin</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Dimensione:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Cerca plugin...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Tutte le categorie</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Cerca in:</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>Copia URL descrizione pagina</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>Vai alla descrizione pagina</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Risultati (visualizzano</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Solo nomi torrent</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Solo abilitati</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>fuori da</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Ovunque</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Disinstalla</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Installa nuovo plugin</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Qui puoi ottenere nuovi plugin motori di ricerca:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Plugin ricerca installati:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Abilitati</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Attenzione: assicurati di essere inr egola con la tua legge locale sul copyright quando scarichi torrent da uno di questi motori di ricerca.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Controllo aggiornamenti</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Plugin ricerca</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Leech</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Motore di ricerca</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Autori seed</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Abilitato</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versione</translation>
    </message>
</context>
</TS>